@@ -604,10 +604,10 @@ def print_to_csv(players,
         player_name = header.de.players[player_num].name.value.decode()
         player_civ = civs[header.de.players[player_num].civ_id]
         player_color = Color(header.de.players[player_num].color_id).name
-        player_team = header.de.players[player_num].resolved_team_id
-        if player_team not in team_dict:
-          team_dict[player_team] = len(team_dict)+1
-        player_team = team_dict[player_team]
+        player_team_id = header.de.players[player_num].resolved_team_id
+        if player_team_id not in team_dict:
+          team_dict[player_team_id] = len(team_dict)+1
+        player_team = "-" if player_team_id == 1 else team_dict[player_team_id]
         player_data[player_num] = {"name": player_name,
                                "civ": player_civ,
                                "color": player_color,
